/*==================================================================================
| vendor256x16.v: vendor-specific ram translation                                  |
|                                                                                  |
|            Copyright 2007 by John Rible, <john@sandpipers.com>                   |
|  Permission is granted for individual non-commercial use, provided this notice   |
|  is included. Contact the author concerning any other use.                       |
|                                                                                  |
|  My Verilog name conventions:  - combinatorial signals have lower-case names     |
|     80 lines per page, 2-up    - registers and flipflops have UPPERCASE NAMES    |
|     84 characters per line     - functions and tasks have Capitalized Names      |
====================================================================================

   This gives the fpga files a common interface to whichever vendor's design tools
   are being used. It assumes a dual-port (read + write) ram clocked on the rising
   edge with separate read/write addresses.

   The project must include the file which contains the proper module.

   NOTE: The Actel ram only has a synchronous read, so it takes two clocks to read
   a value when the address isn't known in advance. Both vendors give ambiguous
   results when reading and writing at the same address.

------------------------------------------------------------------------------------
20070806 jwr created this file.
==================================================================================*/

`timescale 1 ns/100 ps

module ram256x16 ( CLK, WE, WA, MI, RA, MO );

   input         CLK; wire        CLK;

   input         WE;  wire        WE;
   input   [7:0] WA;  wire  [7:0] WA;
   input  [15:0] MI;  wire [15:0] MI;

   input   [7:0] RA;  wire  [7:0] RA;
   output [15:0] MO;  wire [15:0] MO;


// instantiate an Actel ram block --------------------------------------------------

//   actel256x16 m(.WClock(CLK),.WAddress(WA),.Data(MI),.WE(WE),
//                 .RClock(CLK),.RAddress(RA),.Q(MO));

// instantiate an Altera ram block -------------------------------------------------

   altera256x16 m(.wrclock(CLK),.wraddress(WA),.data(MI),.wren(WE),
                  .rdclock(CLK),.rdaddress(RA),.q(MO));

endmodule // vendor256x16 ==========================================================
